test

# configurator report¶

This notebook contains the automatic `configurator` report based on preliminary PE results.

Data provenance

PE summary file | /Users/hestelles/Downloads/posterior_samples-GW190412_final.h5
Data set | SEOBNRv5PHM
md5sum of file | a6c13f798e65b5ce6f30c7a04a69a4da
git revision of data | N/A__DIRTY

Settings

$f_{\rm low}$ | 20.0 Hz
$f_{\rm ref}$ | 20.0 Hz
Max $\ell$ for Nyquist check | 3
Tolerance for railing | 2.0
nbins for railing | 50

## Automatically generated analysis¶

- **Equal masses are excluded at high confidence for this event!

Median mass ratio is below 1/3, highly unequal mass event!**

- $a_{1}$ is well constrained!\n

    2023-04-12  09:49:43 PESummary WARNING : Could not find f_final in input file and one was not passed from the command line. Using 1024.0Hz as default
    2023-04-12  09:49:43 PESummary WARNING : Could not find delta_f in input file and one was not passed from the command line. Using 0.00390625Hz as default
    2023-04-12  09:49:43 PESummary WARNING : Could not find minimum frequency in input file and one was not passed from the command line. Using 20.0Hz as default
    2023-04-12  09:49:44 PESummary WARNING : Could not find f_final in input file and one was not passed from the command line. Using 1024.0Hz as default
    2023-04-12  09:49:44 PESummary WARNING : Could not find delta_f in input file and one was not passed from the command line. Using 0.00390625Hz as default
    2023-04-12  09:49:44 PESummary WARNING : Could not find minimum frequency in input file and one was not passed from the command line. Using 20.0Hz as default
    2023-04-12  09:49:46 PESummary WARNING : Could not find f_final in input file and one was not passed from the command line. Using 1024.0Hz as default
    2023-04-12  09:49:46 PESummary WARNING : Could not find delta_f in input file and one was not passed from the command line. Using 0.00390625Hz as default
    2023-04-12  09:49:46 PESummary WARNING : Could not find minimum frequency in input file and one was not passed from the command line. Using 20.0Hz as default

## Summary of posterior sample parameters¶

| $\mathcal{M}$ | $M_{\rm total}$ | $q$ | $d_{L}$ | $\chi_{1z}$ | $\chi_{2z}$
--- | --- | --- | --- | --- | --- | ---
count | 20000.000000 | 20000.000000 | 20000.000000 | 20000.000000 | 20000.000000 | 20000.000000
mean | 15.269151 | 45.512632 | 0.260995 | 750.172002 | 0.329597 | 0.008401
std | 0.143873 | 2.473913 | 0.041246 | 94.154976 | 0.077479 | 0.301625
min | 14.689509 | 35.637181 | 0.158024 | 353.718338 | -0.133157 | -0.982713
25% | 15.181248 | 43.841781 | 0.233004 | 690.552279 | 0.286035 | -0.149396
50% | 15.257327 | 45.373382 | 0.257615 | 754.673296 | 0.335993 | 0.001422
75% | 15.341430 | 47.079435 | 0.283795 | 813.579619 | 0.381479 | 0.167668
max | 15.995164 | 54.948409 | 0.823447 | 1148.802878 | 0.562419 | 0.973487

## Posterior railing visual check¶

Automatic checks on railing. Note that the recommendations are ad-hoc and may not result in posteriors not being cut off.

|  | Recommendation
--- | --- | ---
chirp_mass | PASSED |
distance | PASSED |
mass_ratio | PASSED |

Plot of selected posterior parameters. All masses are in the detector frame. The red dashed lines show the proposed $\mathcal{M}$ bounds,[14.4284,16.2563]

## MECO frequency check¶

The reference frequency is shown as a dashed green vertical line. If the reference frequency has been modified by the MECO test, the input value appears in red and the new value in green.

|  | Recommendation
--- | --- | ---
f_ref | PASSED |

## Recommended settings¶

seglen | 8.0 sec.
srate | 2048
$f_{\rm start}$ | 13.3333 Hz
$f_{\rm ref}$ | 20.0 Hz
$\mathcal{M}$ bounds | [14.4284,16.2563]

## Extra information¶

Date | 2023-04-12 09:49:39.639055
Script revision | ad853bac7cca41f13b704b059414ff09d8157603__DIRTY
Complete arguments | Namespace(output_dir='examples/test_GW190412', HM=True, q_min=None, ell_max=3, tolerance=2.0, nbins=50, flow=20.0, f_ref=20.0, bounds_tol=0.2, json_file='test.json', report_file='test.pdf', override_safeties=False, debug=False, include_dL_recommendations=False)